Package 'flashCard'

Title: Create a Flash Card
Description: Create a flip over style Flash Card with desired data frame for Shiny application.
Authors: Jiena McLellan [aut, cre] (ORCID: <https://orcid.org/0000-0002-5578-088X>), John Coene [ctb], Michael Condouris [ctb] (ORCID: <https://orcid.org/0000-0002-8862-4250>)
Maintainer: Jiena McLellan <[email protected]>
License: MIT + file LICENSE
Version: 0.1.1
Built: 2026-05-27 10:32:49 UTC
Source: https://github.com/jienagu/flashcard

Help Index


Create a flash card

Description

Create a flash card with desired data frame

Usage

flashCard(
  data,
  frontColor = "#090e87",
  backColor = "#3443c9",
  front_text_color = "white",
  back_text_color = "white",
  width = NULL,
  height = NULL,
  elementId = NULL
)

Arguments

data

df with front and back columns

frontColor

frond side background color

backColor

back side background color

front_text_color

frond text color

back_text_color

back text color

width

width

height

height

elementId

element id

Examples

df1 <- data.frame(
front = c("Title front","contentfront", "content second line"),
back = c("Title back","content back", "second line")
)
flashCard(df1, elementId = "card", front_text_color = "grey")

Shiny bindings for flashCard

Description

Output and render functions for using flashCard within Shiny applications and interactive Rmd documents.

Usage

flashCardOutput(outputId, width = "300px", height = "135px")

renderFlashCard(expr, env = parent.frame(), quoted = FALSE)

Arguments

outputId

output variable to read from

width

width of the widget

height

height of the widget

expr

An expression that generates a flashCard

env

The environment in which to evaluate expr.

quoted

Is expr a quoted expression (with quote())? This is useful if you want to save an expression in a variable.